@@ -10,10 +10,10 @@ use alloc::vec::Vec;
 
 use serde::{de::DeserializeOwned, Serialize};
 
-use crate::io::{self, Write};
-
+use crate::errors::Errors;
 #[cfg(feature = "std")]
 use crate::io::Read;
+use crate::io::{self, Write};
 
 use super::{Headers, Method, SendHeaders, SendStatus};
 
@@ -89,7 +89,7 @@ pub trait Session<'a> {
     fn invalidate(&mut self) -> Result<bool, SessionError>;
 }
 
-pub trait Request<'a>: Headers {
+pub trait Request<'a>: Headers + Errors {
     type Read<'b>: io::Read<Error = Self::Error>
     where
         Self: 'b;
@@ -102,12 +102,6 @@ pub trait Request<'a>: Headers {
     where
         Self: 'b;
 
-    #[cfg(not(feature = "std"))]
-    type Error: fmt::Debug + fmt::Display;
-
-    #[cfg(feature = "std")]
-    type Error: std::error::Error + Send + Sync + 'static;
-
     fn query_string(&self) -> Cow<'_, str>;
 
     fn attrs(&self) -> Self::Attributes<'_>;
@@ -175,15 +169,9 @@ pub trait ResponseWrite<'a>: io::Write {
     fn complete(self) -> Result<Completion, Self::Error>;
 }
 
-pub trait Response<'a>: SendStatus<'a> + SendHeaders<'a> {
+pub trait Response<'a>: SendStatus<'a> + SendHeaders<'a> + Errors {
     type Write<'b>: ResponseWrite<'b, Error = Self::Error>;
 
-    #[cfg(not(feature = "std"))]
-    type Error: fmt::Debug + fmt::Display;
-
-    #[cfg(feature = "std")]
-    type Error: std::error::Error + Send + Sync + 'static;
-
     fn send_bytes(
         self,
         request: impl Request<'a>,
@@ -325,7 +313,7 @@ impl From<std::fs::File> for Body {
     fn from(f: std::fs::File) -> Self {
         Body::Read(
             f.metadata().map_or(None, |md| Some(md.len() as usize)),
-            io::StdIO(f).into_dyn_read(),
+            io::StdRead(f).into_dyn_read(),
         )
     }
 }
