@@ -1,7 +1,10 @@
-#[cfg(feature = "experimental")]
+#[cfg(all(feature = "alloc", feature = "experimental"))]
 pub mod nonblocking {
     use core::future::Future;
 
+    extern crate alloc;
+    use alloc::boxed::Box;
+
     pub trait Blocker {
         fn block<F>(f: F) -> F::Output
         where
